DoctorCommand class

Check the health of the Claude Dart/Flutter Toolkit installation

Inheritance

Constructors

DoctorCommand()

Properties

argParser → ArgParser
Command-specific argument parser
no setterinherited
description String
Command description
no setteroverride
examples List<String>
Command usage examples
no setteroverride
hashCode int
The hash code for this object.
no setterinherited
name String
Command name
no setteroverride
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
verbose bool
Whether to show verbose output
getter/setter pairinherited

Methods

getProjectDirectory() String
Get current project directory
inherited
hasClaudeConfig() bool
Check if CLAUDE.md exists
inherited
isInProject() bool
Check if we're in a Dart/Flutter project
inherited
loadClaudeConfig() Future<Map<String, dynamic>>
Load CLAUDE.md configuration
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
parseArgs(List<String> arguments) → ArgResults
Parse arguments and handle help
inherited
printError(String message) → void
Print error message
inherited
printHelp() → void
Print command help
inherited
printInfo(String message) → void
Print info message
inherited
printSuccess(String message) → void
Print success message
inherited
printVerbose(String message) → void
Print verbose message
inherited
printWarning(String message) → void
Print warning message
inherited
run(List<String> arguments) Future<int>
Run the command with the given arguments
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited