ProjectConfig class

Constructors

ProjectConfig({required String type, required String description, required UsageType usageType, required ProjectSize size, required TeamSize teamSize, String? architecture, String? stateManagement, required List<String> focusAreas, required List<String> capabilities, required bool includeTests, required bool includeAnalysis, required bool includeSecurity, required bool includePerformance})

Properties

architecture String?
final
capabilities List<String>
final
description String
final
focusAreas List<String>
final
hashCode int
The hash code for this object.
no setterinherited
includeAnalysis bool
final
includePerformance bool
final
includeSecurity bool
final
includeTests bool
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
size ProjectSize
final
stateManagement String?
final
teamSize TeamSize
final
type String
final
usageType UsageType
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited