ToolkitLogger class

Central logging and UI utility for Claude Toolkit

Constructors

ToolkitLogger()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Properties

internal → Logger
Get the underlying mason logger for advanced usage
no setter

Static Methods

boxSummary(String title, List<String> lines) → void
Draw a boxed summary
detail(String message) → void
err(String message) → void
info(String message) → void
showBanner() → void
Show a stylized welcome banner
spinner(String message) → Progress
Create a loading spinner
success(String message) → void
warn(String message) → void