BaseCommand class abstract
Base class for all CLI commands
- Implementers
Constructors
Properties
- argParser → ArgParser
-
Command-specific argument parser
no setter
- description → String
-
Command description
no setter
-
examples
→ List<
String> -
Command usage examples
no setter
- hashCode → int
-
The hash code for this object.
no setterinherited
- name → String
-
Command name
no setter
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- verbose ↔ bool
-
Whether to show verbose output
getter/setter pair
Methods
-
getProjectDirectory(
) → String - Get current project directory
-
hasClaudeConfig(
) → bool - Check if CLAUDE.md exists
-
isInProject(
) → bool - Check if we're in a Dart/Flutter project
-
loadClaudeConfig(
) → Future< Map< String, dynamic> > - Load CLAUDE.md configuration
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
parseArgs(
List< String> arguments) → ArgResults - Parse arguments and handle help
-
printError(
String message) → void - Print error message
-
printHelp(
) → void - Print command help
-
printInfo(
String message) → void - Print info message
-
printSuccess(
String message) → void - Print success message
-
printVerbose(
String message) → void - Print verbose message
-
printWarning(
String message) → void - Print warning message
-
run(
List< String> arguments) → Future<int> - Run the command with the given arguments
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited