ClaudeToolkit class
Main CLI runner for the Claude Dart/Flutter Toolkit
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
run(
List< String> arguments) → Future<int> - Run the CLI with the provided arguments
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Methods
-
getProjectDirectory(
) → String - Get the current project directory
-
hasClaudeConfig(
) → bool - Check if CLAUDE.md exists in current project
-
isInProject(
) → bool - Check if we're in a Dart/Flutter project
Constants
- description → const String
- version → const String